@@ -200,9 +200,19 @@ class NodeSamba:
         tmp_file.close()
 
         data = json.loads(raw.decode())
+
+        _LOGGER.debug("Node Pro measurements loaded: %s", data)
+
+        try:
+            # Handle a single measurement returned in a list:
+            measurements = data["measurements"][0].items()
+        except KeyError:
+            # Handle a single measurement returned as a standalone dict:
+            measurements = data["measurements"].items()
+
         data["measurements"] = {
             _get_normalized_metric_name(pollutant): value
-            for pollutant, value in data["measurements"][0].items()
+            for pollutant, value in measurements
         }
         data["status"]["sensor_life"] = {
             _get_normalized_metric_name(pollutant): value
@@ -252,6 +262,9 @@ class NodeSamba:
                     for header, value in row.items():
                         _data[_get_normalized_metric_name(header)] = value
                     data.append(_data)
+
+            _LOGGER.debug("Node Pro history loaded: %s", data)
+
             return data
 
         data = {}
